pub enum NoToolSelector {}Trait Implementations
Sourceimpl Clone for NoToolSelector
impl Clone for NoToolSelector
Sourcefn clone(&self) -> NoToolSelector
fn clone(&self) -> NoToolSelector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NoToolSelector
impl Debug for NoToolSelector
Sourceimpl<'de> Deserialize<'de> for NoToolSelector
impl<'de> Deserialize<'de> for NoToolSelector
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for NoToolSelector
impl Hash for NoToolSelector
Sourceimpl JsonSchema for NoToolSelector
impl JsonSchema for NoToolSelector
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NoToolSelector
impl PartialEq for NoToolSelector
Sourceimpl Serialize for NoToolSelector
impl Serialize for NoToolSelector
Sourceimpl ToolSelector<NoTools> for NoToolSelector
impl ToolSelector<NoTools> for NoToolSelector
impl Copy for NoToolSelector
impl Eq for NoToolSelector
impl StructuralPartialEq for NoToolSelector