pub struct TextTurnState<T: Toolset> {
pub request_id: Option<String>,
pub model: String,
pub assistant_turn: Vec<AssistantTurnItem>,
pub tool_calls: Vec<T::ToolCall>,
pub finish_reason: Option<FinishReason>,
pub usage: Option<Usage>,
pub committed_turn: Option<CommittedTurn>,
}Fields
request_id: Option<String>model: Stringassistant_turn: Vec<AssistantTurnItem>tool_calls: Vec<T::ToolCall>finish_reason: Option<FinishReason>usage: Option<Usage>committed_turn: Option<CommittedTurn>Implementations
Sourceimpl<T> TextTurnState<T>where
T: Toolset,
impl<T> TextTurnState<T>where
T: Toolset,
pub fn assistant_text(&self) -> String
Sourcepub fn apply(
&mut self,
event: &TextTurnEvent<T>,
) -> Result<(), TextTurnReductionError>
pub fn apply( &mut self, event: &TextTurnEvent<T>, ) -> Result<(), TextTurnReductionError>
Apply a streaming event to advance this turn state.
Returns an error if the turn has already completed.
Sourcepub fn finish(self) -> Result<TextTurnResult<T>, TextTurnReductionError>
pub fn finish(self) -> Result<TextTurnResult<T>, TextTurnReductionError>
Finalize the accumulated state into a completed turn result.
Returns TextTurnReductionError::Incomplete if the turn has not yet
received a Completed event, and
TextTurnReductionError::EmptyAssistantOutput if the completed turn
produced no assistant items.